package com.ruoyi.web.controller.system;

import java.util.List;

import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.system.domain.SysRepo;
import com.ruoyi.system.service.ISysRepoService;
import org.springframework.web.multipart.MultipartFile;

/**
 * 仓库管理Controller
 * 
 * @author ruoyi
 * @date 2025-05-15
 */
@RestController
@RequestMapping("/system/repo")
public class SysRepoController extends BaseController
{
    @Autowired
    private ISysRepoService sysRepoService;

    /**
     * 查询仓库列表
     */
    @PreAuthorize("@ss.hasPermi('system:repo:list')")
    @GetMapping("/list")
    public AjaxResult list(SysRepo sysRepo)
    {
        List<SysRepo> list = sysRepoService.selectSysRepoList(sysRepo);
        return success(list);
    }


    /**
     * 获取仓库详细信息
     */
    @PreAuthorize("@ss.hasPermi('system:repo:query')")
    @GetMapping(value = "/{repoId}")
    public AjaxResult getInfo(@PathVariable("repoId") Long repoId)
    {
        return success(sysRepoService.selectSysRepoByRepoId(repoId));
    }

    /**
     * 新增仓库
     */
    @PreAuthorize("@ss.hasPermi('system:repo:add')")
    @Log(title = "新增仓库", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody SysRepo sysRepo)
    {
        return toAjax(sysRepoService.insertSysRepo(sysRepo));
    }

    @PreAuthorize("@ss.hasPermi('system:repo:addByfile')")
    @Log(title = "新增仓库文件", businessType = BusinessType.INSERT)
    public AjaxResult addByfile(@RequestParam("parent_id") Long parent_id,@RequestParam("file") MultipartFile file)
    {
        if(!file.isEmpty()){
            SysRepo sysRepo = new SysRepo();
            sysRepo.setRepoName(file.getOriginalFilename());
            sysRepo.setParentId(parent_id);
            sysRepo.setRepoType("file");
            sysRepo.setRepoLevel(sysRepoService.selectSysRepoByRepoId(parent_id).getRepoLevel() + 1);
            sysRepo.setRepoStatus("public");
            sysRepo.setCreateBy(getLoginUser().getUserId());
            return toAjax(sysRepoService.insertSysRepo(sysRepo));
        }else{
            return error("上传文件异常，请联系管理员");
        }

    }

    /**
     * 修改仓库
     */
    @PreAuthorize("@ss.hasPermi('system:repo:edit')")
    @Log(title = "修改仓库", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody SysRepo sysRepo)
    {
        return toAjax(sysRepoService.updateSysRepo(sysRepo));
    }

    /**
     * 删除仓库
     */
    @PreAuthorize("@ss.hasPermi('system:repo:remove')")
    @Log(title = "删除仓库", businessType = BusinessType.DELETE)
	@DeleteMapping("/{repoIds}")
    public AjaxResult remove(@PathVariable Long[] repoIds)
    {
        return toAjax(sysRepoService.deleteSysRepoByRepoIds(repoIds));
    }
}
